==> yq-4.1.0.tar.gz: yq-4.1.0/pkg/yqlib/operator_assign.go <==
package yqlib

import "container/list"

type AssignOpPreferences struct {
	UpdateAssign bool
}

func AssignUpdateOperator(d *dataTreeNavigator, matchingNodes *list.List, pathNode *PathTreeNode) (*list.List, error) {
	lhs, err := d.GetMatchingNodes(matchingNodes, pathNode.Lhs)
	if err != nil {
		return nil, err
	}
	preferences := pathNode.Operation.Preferences.(*AssignOpPreferences)

	var rhs *list.List
	if !preferences.UpdateAssign {
		rhs, err = d.GetMatchingNodes(matchingNodes, pathNode.Rhs)
	}

	for el := lhs.Front(); el != nil; el = el.Next() {
		candidate := el.Value.(*CandidateNode)

		if preferences.UpdateAssign {
			rhs, err = d.GetMatchingNodes(nodeToMap(candidate), pathNode.Rhs)
		}

		if err != nil {
			return nil, err
		}

		// grab the first value
		first := rhs.Front()

		if first != nil {
			candidate.UpdateFrom(first.Value.(*CandidateNode))
		}
	}
	// // if there was nothing given, perhaps we are creating a new yaml doc
	// if matchingNodes.Len() == 0 {
	// 	log.Debug("started with nothing, returning LHS, %v", lhs.Len())
	// 	return lhs, nil
	// }
	return matchingNodes, nil
}

// does not update content or values
func AssignAttributesOperator(d *dataTreeNavigator, matchingNodes *list.List, pathNode *PathTreeNode) (*list.List, error) {
	lhs, err := d.GetMatchingNodes(matchingNodes, pathNode.Lhs)
	if err != nil {
		return nil, err
	}
	for el := lhs.Front(); el != nil; el = el.Next() {
		candidate := el.Value.(*CandidateNode)

		rhs, err := d.GetMatchingNodes(nodeToMap(candidate), pathNode.Rhs)

		if err != nil {
			return nil, err
		}

		// grab the first value
		first := rhs.Front()

		if first != nil {
			candidate.UpdateAttributesFrom(first.Value.(*CandidateNode))
		}
	}
	return matchingNodes, nil
}

==> yq-4.2.1.tar.gz: yq-4.2.1/pkg/yqlib/operator_assign.go <==
package yqlib

import "container/list"

type AssignOpPreferences struct {
	UpdateAssign bool
}

func AssignUpdateOperator(d *dataTreeNavigator, matchingNodes *list.List, pathNode *PathTreeNode) (*list.List, error) {
	lhs, err := d.GetMatchingNodes(matchingNodes, pathNode.Lhs)
	if err != nil {
		return nil, err
	}
	preferences := pathNode.Operation.Preferences.(*AssignOpPreferences)

	var rhs *list.List
	if !preferences.UpdateAssign {
		rhs, err = d.GetMatchingNodes(matchingNodes, pathNode.Rhs)
	}

	for el := lhs.Front(); el != nil; el = el.Next() {
		candidate := el.Value.(*CandidateNode)

		if preferences.UpdateAssign {
			rhs, err = d.GetMatchingNodes(nodeToMap(candidate), pathNode.Rhs)
		}

		if err != nil {
			return nil, err
		}

		// grab the first value
		first := rhs.Front()

		if first != nil {
			rhsCandidate := first.Value.(*CandidateNode)
			rhsCandidate.Node = UnwrapDoc(rhsCandidate.Node)
			candidate.UpdateFrom(rhsCandidate)
		}
	}
	// // if there was nothing given, perhaps we are creating a new yaml doc
	// if matchingNodes.Len() == 0 {
	// 	log.Debug("started with nothing, returning LHS, %v", lhs.Len())
	// 	return lhs, nil
	// }
	return matchingNodes, nil
}

// does not update content or values
func AssignAttributesOperator(d *dataTreeNavigator, matchingNodes *list.List, pathNode *PathTreeNode) (*list.List, error) {
	lhs, err := d.GetMatchingNodes(matchingNodes, pathNode.Lhs)
	if err != nil {
		return nil, err
	}
	for el := lhs.Front(); el != nil; el = el.Next() {
		candidate := el.Value.(*CandidateNode)

		rhs, err := d.GetMatchingNodes(nodeToMap(candidate), pathNode.Rhs)

		if err != nil {
			return nil, err
		}

		// grab the first value
		first := rhs.Front()

		if first != nil {
			candidate.UpdateAttributesFrom(first.Value.(*CandidateNode))
		}
	}
	return matchingNodes, nil
}
